mafw.tools.file\_tools
======================

.. automodule:: mafw.tools.file_tools

   
   .. rubric:: Functions

   .. autosummary::
   
      file_checksum
      remove_widow_db_rows
      verify_checksum
   